@@ -128,7 +128,8 @@ def update():
     G = get_backend(backend)(settings)
     mwc_home = Path(settings["work_dir"])
     mwc_home.mkdir(mode=WORK_DIR_PERMISSIONS, parents=True, exist_ok=True)
-    for course in curr['courses']:
+    if settings['course'] in curr['courses']:
+        course = settings['course']
         course_dir = mwc_home / course['slug']
         course_dir.mkdir(mode=WORK_DIR_PERMISSIONS, exist_ok=True)
         for unit in course['units']:
@@ -151,4 +152,6 @@ def update():
                             G.init_module(module, module_dir)
                         except Exception as e:
                             msg =  traceback.format_exception(type(e), e, e.__traceback__)
-                            print(error(''.join(msg)))
+                            click.echo(error(''.join(msg)))
+    else:
+        click.echo(warning("Error: You are enrolled in {settings['course']}, but this course is not available. Please run mwc setup again."))
